<?php
/**
 * Rewrite fonts added by other themes and plugins.
 *
 * @package   fonts-plugin-pro
 * @copyright Copyright (c) 2019, Danny Cooper
 * @license   http://opensource.org/licenses/gpl-2.0.php GNU Public License
 */

/**
 * Rewrite URLs to be locally hosted.
 *
 * @param string $src URL of the stylesheet.
 * @param string $handle handle of the stylesheet.
 *
 * @return string @src New URL of the stylesheet.
 */
function fpp_switch_stylesheet_src( $src, $handle = '' ) {
	if ( $handle === 'olympus-google-fonts' ) {
		return $src;
	}

	$src = preg_replace( '/&ver=([^&]+)/', '', $src );
	if ( false !== strpos( $src, '//fonts.googleapis.com/css' ) ) {
		$font = new FPP_Host_Google_Fonts_Locally( $src );
		$font->set_font_format( fpp_get_font_format() );
		$src = $font->get_url();
	}
	return $src;
}
add_filter( 'style_loader_src', 'fpp_switch_stylesheet_src', 10, 2 );

/**
 * Rewrite RevSlider URLs to be locally hosted.
 *
 * @param string $string CSS output.
 *
 * @return string $string String with URLs replaced.
 */
function fpp_rev_slider_rewrite( $string ) {
	$rev_slider_global = json_decode( get_option( 'revslider-global-settings' ) );

	if ( $rev_slider_global->fontdownload == 'off' ) {
		$url = fpp_extract_url( $string );

		$local_url = fpp_switch_stylesheet_src( $url );

		return str_replace( $url, $local_url, $string );
	}

	return $string;
}
add_filter( 'revslider_printCleanFontImport', 'fpp_rev_slider_rewrite' );

/**
 * Extract URL from CSS style code.
 *
 * @param string $string CSS input.
 *
 * @return string $string The found URL.
 */
function fpp_extract_url( $string ) {
	preg_match( '/href="(.*?)"/', $string, $matches );
	return $matches[1];
}
